@@ -1,12 +1,14 @@
 #ifndef FRAMEWORK_H
 #define FRAMEWORK_H
 
+#include <iostream>
 #include <string>
 #include <vector>
+#include <map>
 
 #include "SDL.h"
-#include "net/net2.h"
 #include <GL/gl.h>
+#include "grapple/grapple.h"
 
 #include "stuff.hpp"
 #include "Interface.hpp"
@@ -14,6 +16,7 @@
 #include "Ball.hpp"
 #include "Player.hpp"
 #include "Camera.hpp"
+#include "Buffer.hpp"
 
 class Ball;
 
@@ -37,8 +40,21 @@ public:
 		SDL_TimerID timer;
 	};
 
+	struct Peer {
+		std::string name;
+		Player* player;
+		bool ready;
+
+		inline Peer(std::string id)
+		: name(id), player(NULL), ready(false) {}
+		// needed by std::map, do not use
+		inline Peer() {}
+	};
+
 	//! holds the actual networking state
 	enum Networkstate {
+		//! initialization isn't finished yet
+		UNINITIALIZED,
 		//! the server is waiting for a client to arrive
 		WAITING,
 		//! the client tries to connect to a server
@@ -66,7 +82,7 @@ public:
 	~Framework();
 
 	//! load a texture into OpenGL
-	/*!	\param filename the file containing the texture (actually .bmp)
+	/*!	\param filename the file containing the texture (has to be readable by SDL_image)
 		\result the number given to the texture for further binding
 	*/
 	GLuint loadTexture(const std::string& filename);
@@ -100,6 +116,8 @@ public:
 	/*!	\param index the timer's number which was given by addTimer()
 	*/
 	void removeTimer(int index);
+
+	inline const std::vector<Player*>& getPlayers() { return player; }
 protected:
 	//! enter the event loop, which indefinitely runs and processes events
 	void loop();
@@ -112,29 +130,14 @@ protected:
 	*/
 	void togglePause(bool pause, bool external);
 
-	//! opens an udp socket on the listening port
-	/*! The Clients listening port is the configured port number + 1.
-	    Shuts the game down on failure.
-	*/
-	void startListen();
+	virtual void ping()=0;
 
-	//! send a packet to a connected player
-	/*!	\param receiver pointer to the receiver's data (host)
-		\param data the data to be sent as NOT null terminated char array
-		\param size the size of the data array in bytes
-	*/
-	void sendPacket(Peer* receiver, char* data, int size);
+	//! process message queue, send periodical packages, called by loop()
+	virtual void doNetworking()=0;
 
-	//! resolves a hostname and creates an according peer
-	/*!	\param hostname the host's dns name or ip address
-		\result the created Peer structure on success, otherwise NULL
-	*/
-	Peer* resolveHost(const std::string& hostname);
+	virtual void sendPacket(Buffer& data, bool reliable)=0;
 
-	//! vector holding all connected peers
-	/*! Actually we only support one connection. This can be extended in future.
-	*/
-	std::vector<Peer> peer;
+	void sendSimplePacket(PacketType t);
 
 	//! our Camera object setting up the viewport
 	Camera camera;
@@ -155,15 +158,11 @@ protected:
 		If noone is connected as client, the server provides the famous "Mr. Wand" called opponent.
 		Better not try to beat him!
 	*/
-	std::vector<Player> player;
+	std::vector<Player*> player;
 
-	//! our actual networking protocol version
-	unsigned int version;
+	std::map<grapple_user, Peer> peer;
+	grapple_user localid;
 
-	//! the UDP port number to listen on
-	unsigned short listenport;
-	//! the UDP port number to send packets to
-	unsigned short sendport;
 	//! pause state
 	/*! Is 0 if not paused and otherwise holds the ticks (ms) which need to be processed after the pause. */
 	unsigned int paused;
@@ -190,20 +189,10 @@ private:
 	//! update the game per frame, therefore called by loop()
 	virtual void updateGame(int ticks)=0;
 	//! process an occured score (the ball went out of the field), called by detectCol()
-	virtual void score(Side side)=0;
+	virtual void doScore(Side side)=0;
 	//! serve the ball, i.e. the player wants to kick it off, called by loop()
 	virtual void serveBall()=0;
 
-	//! process an incoming packet, called by loop()
-	virtual void receivePacket(Peer* sender, char* data, int size)=0;
-
-	//! try to find a peer, if not found, create it
-	/*! This one's called by loop() whenever a packet arrives. It's helpful to know who sent the packet.
-		\param host the host ip address of the peer
-		\result pointer to the found/created Peer
-	*/
-	Peer* getCreatePeer(unsigned int host);
-
 	/*! the SDL video surface */
 	SDL_Surface *surface;
 
